@@ -15,11 +15,13 @@ summary.zelig<-function(object, subset = NULL, CI=95,
       X1 <- rbind(X1, object$x1[[i]])
   }
   if (is.null(dim(X))) {
-    X <- matrix(X, ncol = 1)
-    colnames(X) <- "(Intercept)"
-    if (!is.null(X1)) {
-      X1 <- matrix(X1, ncol = 1)
-      colnames(X1) <- "(Intercept)"
+    if (!is.null(X)) { 
+      X <- matrix(X, ncol = 1)
+      colnames(X) <- "(Intercept)"
+      if (!is.null(X1)) {
+        X1 <- matrix(X1, ncol = 1)
+        colnames(X1) <- "(Intercept)"
+      }
     }
   }
   if (is.numeric(subset)) {
@@ -36,7 +38,7 @@ summary.zelig<-function(object, subset = NULL, CI=95,
       qi.stats[[i]] <- t(qi.stats[[i]])
     if (is.table(qi.stats[[i]]))
       qi.stats[[i]] <- t(as.matrix(qi.stats[[i]]))
-    if (is.null(subset) && nrow(X) > 1)
+    if (all(c(is.null(subset), !is.null(X), nrow(X) > 1)))
       object$qi.name[i] <- paste("Pooled", object$qi.name[[i]])
   }
   names(qi.stats) <- names(object$qi)
